┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinview.h
diff options
context:
space:
mode:
authorDavid Faure <[email protected]>2008-01-21 16:12:25 +0000
committerDavid Faure <[email protected]>2008-01-21 16:12:25 +0000
commitf9aeb825c605ec4ca8b95aae0be1b441ca8ceb91 (patch)
tree9acb36536cb48dded3b27342b9154475677388c6 /src/dolphinview.h
parent418eed751192d4dcf1b537a74863920d592bea10 (diff)
merge -c764347 by Peter, needed for dolphinpart bugfixing
svn path=/branches/KDE/4.0/kdebase/apps/; revision=764379
Diffstat (limited to 'src/dolphinview.h')
-rw-r--r--src/dolphinview.h28
1 files changed, 18 insertions, 10 deletions
diff --git a/src/dolphinview.h b/src/dolphinview.h
index 60e29b4d5..485748751 100644
--- a/src/dolphinview.h
+++ b/src/dolphinview.h
@@ -119,21 +119,23 @@ public:
};
/**
* @param parent Parent widget of the view.
* @param url Specifies the content which should be shown.
* @param dirLister Used directory lister. The lister is not owned
* by the view and won't get deleted.
* @param dolphinModel Used directory model. The model is not owned
* by the view and won't get deleted.
* @param proxyModel Used proxy model which specifies the sorting. The
* model is not owned by the view and won't get
* deleted.
*/
DolphinView(QWidget* parent,
const KUrl& url,
KDirLister* dirLister,
DolphinModel* dolphinModel,
- DolphinSortFilterProxyModel* proxyModel);
+ DolphinSortFilterProxyModel* proxyModel,
+ KActionCollection* actionCollection);
virtual ~DolphinView();
@@ -616,6 +618,12 @@ private slots:
*/
void slotPreviewJobFinished(KJob* job);
+ /**
+ * Opens the dialog for creating a directory. Is connected
+ * with the key shortcut for "new directory" (F10).
+ */
+ void createDir();
+
private:
void loadDirectory(const KUrl& url, bool reload = false);
@@ -119,21 +119,23 @@ public:
};
/**
- * @param parent Parent widget of the view.
- * @param url Specifies the content which should be shown.
- * @param dirLister Used directory lister. The lister is not owned
- * by the view and won't get deleted.
- * @param dolphinModel Used directory model. The model is not owned
- * by the view and won't get deleted.
- * @param proxyModel Used proxy model which specifies the sorting. The
- * model is not owned by the view and won't get
- * deleted.
+ * @param parent Parent widget of the view.
+ * @param url Specifies the content which should be shown.
+ * @param dirLister Used directory lister. The lister is not owned
+ * by the view and won't get deleted.
+ * @param dolphinModel Used directory model. The model is not owned
+ * by the view and won't get deleted.
+ * @param proxyModel Used proxy model which specifies the sorting. The
+ * model is not owned by the view and won't get
+ * deleted.
+ * @param actionCollection Action collection which contains the menu actions.
*/
DolphinView(QWidget* parent,